from setuptools import setup, find_packages

setup(
    name='publica',
    version='0.0.0',
    author='Rain Star',
    description="Yet another library server for home",
    packages=find_packages(),
    install_requires=[],
)
